<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>ActionWindow</name>
    <message>
        <location filename="../src/ui/actionwindow.ui" line="14"/>
        <source>Install Game</source>
        <translation>Установка игры</translation>
    </message>
    <message>
        <location filename="../src/ui/actionwindow.ui" line="32"/>
        <source>Installing game .... from file .....</source>
        <translation>Установка игры</translation>
    </message>
    <message>
        <location filename="../src/ui/actionwindow.ui" line="92"/>
        <source>Installation Steps:</source>
        <translation>Шаги инсталляции:</translation>
    </message>
    <message>
        <location filename="../src/ui/actionwindow.ui" line="188"/>
        <location filename="../src/actionwindow.cpp" line="35"/>
        <source>Return</source>
        <translation>Вернуться</translation>
    </message>
    <message>
        <location filename="../src/actionwindow.cpp" line="38"/>
        <source>Progress</source>
        <translation>Прогресс</translation>
    </message>
    <message>
        <location filename="../src/actionwindow.cpp" line="48"/>
        <source>Abort installation?</source>
        <translation>Прервать установку?</translation>
    </message>
    <message>
        <location filename="../src/actionwindow.cpp" line="49"/>
        <source>Are you sure you want to abort installation?</source>
        <translation>Вы уверены, что хотите прервать установку?</translation>
    </message>
    <message>
        <location filename="../src/actionwindow.cpp" line="77"/>
        <source>Failed!</source>
        <translation>Ошибка!</translation>
    </message>
    <message>
        <location filename="../src/actionwindow.cpp" line="90"/>
        <source>Warning: </source>
        <translation>Предупреждение:</translation>
    </message>
    <message>
        <location filename="../src/actionwindow.cpp" line="128"/>
        <source>Step %1</source>
        <translation>Шаг %1</translation>
    </message>
    <message>
        <location filename="../src/actionwindow.cpp" line="191"/>
        <source>Remove dir?</source>
        <translation>Удалить каталог?</translation>
    </message>
    <message>
        <location filename="../src/actionwindow.cpp" line="192"/>
        <source>Directory %1 already exists, perhaps from the previous installation.&lt;br /&gt;Do you want to delete it and continue installation?</source>
        <translation>Каталог %1 существует, возможно с предыдущей инсталляции.&lt;br /&gt;Удалить его и продолжить инсталляцию?</translation>
    </message>
    <message>
        <location filename="../src/actionwindow.cpp" line="200"/>
        <source>Directory %1 already exists.&lt;br /&gt;Please, delete it manually and repeat an installation.</source>
        <translation>Каталог %1 существует.&lt;br /&gt;Удалите его вручную и повторите инсталляцию.</translation>
    </message>
    <message>
        <location filename="../src/actionwindow.cpp" line="227"/>
        <source>Updating status</source>
        <translation>Обновление статуса</translation>
    </message>
    <message>
        <location filename="../src/actionwindow.cpp" line="252"/>
        <source>Running postinstall</source>
        <translation>Выполнение послеустановочных команд</translation>
    </message>
    <message>
        <location filename="../src/actionwindow.cpp" line="269"/>
        <source>Postinstall script failed!&lt;br /&gt;Please, check the output:&lt;br /&gt;</source>
        <translation>Послеустановочный скрипт вернул ошибку!&lt;br /&gt;Проверьте его вывод:&lt;br /&gt;</translation>
    </message>
</context>
<context>
    <name>FindIpkWindow</name>
    <message>
        <location filename="../src/ui/findipkwindow.ui" line="20"/>
        <source>Find IPK file...</source>
        <translation>Найти .ipk файл...</translation>
    </message>
    <message>
        <location filename="../src/ui/findipkwindow.ui" line="29"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:18pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:22pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/findipkwindow.ui" line="78"/>
        <source>Open Game Website</source>
        <translation>Открыть сайт игры</translation>
    </message>
    <message>
        <source>Find .IPK on Internet...</source>
        <translation type="obsolete">Найти .ipk в интернете...</translation>
    </message>
    <message>
        <location filename="../src/ui/findipkwindow.ui" line="97"/>
        <source>Locate .IPK file in different folder...</source>
        <translation>Найти .ipk в другой папке...</translation>
    </message>
    <message>
        <location filename="../src/findipkwindow.cpp" line="16"/>
        <source>You have to download original game file with name </source>
        <translation>Вы должны скачать оригинальный файл с именем </translation>
    </message>
    <message>
        <location filename="../src/findipkwindow.cpp" line="18"/>
        <source> and save it into the/Downloads folder.</source>
        <translation>и сохранить его в каталог /Downloads.</translation>
    </message>
    <message>
        <location filename="../src/findipkwindow.cpp" line="40"/>
        <source>If you&apos;re sure that you downloaded right .ipk file to MyDocs/Downloads directory, then click &quot;Done&quot;</source>
        <translation>Если вы уверены, что скачали правильный файл в папку /Downloads, тогда нажмите &quot;Вернуться&quot;</translation>
    </message>
    <message>
        <location filename="../src/findipkwindow.cpp" line="43"/>
        <source>Done</source>
        <translation>Вернуться</translation>
    </message>
    <message>
        <location filename="../src/findipkwindow.cpp" line="50"/>
        <source>Locate IPK File</source>
        <translation>Найти .ipk файл</translation>
    </message>
    <message>
        <location filename="../src/findipkwindow.cpp" line="52"/>
        <source>IPK (*.ipk)</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>InstallWindow</name>
    <message>
        <location filename="../src/installwindow.cpp" line="16"/>
        <source>Installing</source>
        <translation>Установка</translation>
    </message>
    <message>
        <location filename="../src/installwindow.cpp" line="18"/>
        <source>Install game</source>
        <translation>Установка игры</translation>
    </message>
    <message>
        <location filename="../src/installwindow.cpp" line="38"/>
        <source>Notes</source>
        <translation>Заметки</translation>
    </message>
    <message>
        <location filename="../src/installwindow.cpp" line="42"/>
        <source>Game installed!</source>
        <translation>Игра установлена!</translation>
    </message>
    <message>
        <source>Running postinstall</source>
        <translation type="obsolete">Выполнение послеустановочных команд</translation>
    </message>
    <message>
        <location filename="../src/installwindow.cpp" line="60"/>
        <source>Prepare desktop shortcut</source>
        <translation>Подготовка иконок</translation>
    </message>
    <message>
        <location filename="../src/installwindow.cpp" line="69"/>
        <location filename="../src/installwindow.cpp" line="77"/>
        <location filename="../src/installwindow.cpp" line="83"/>
        <source>Cannot create directory %1</source>
        <translation>Невозможно создать каталог %1</translation>
    </message>
    <message>
        <location filename="../src/installwindow.cpp" line="100"/>
        <source>Cannot copy icon </source>
        <translation>Невозможно скопировать иконку </translation>
    </message>
    <message>
        <location filename="../src/installwindow.cpp" line="124"/>
        <source>Cannot create .desktop file </source>
        <translation>Невозможно создать .desktop файл </translation>
    </message>
    <message>
        <location filename="../src/installwindow.cpp" line="137"/>
        <source>Cannot create DBUS .service file </source>
        <translation>Невозможно создать dbus .service файл </translation>
    </message>
    <message>
        <location filename="../src/installwindow.cpp" line="153"/>
        <source>Prepare files and symlinks</source>
        <translation>Подготовка файлов и ссылок</translation>
    </message>
    <message>
        <location filename="../src/installwindow.cpp" line="167"/>
        <source>Cannot copy binary file </source>
        <translation>Невозможно скопировать бинарный файл </translation>
    </message>
    <message>
        <location filename="../src/installwindow.cpp" line="202"/>
        <source>Unpack archive (it may take a while)</source>
        <translation>Распаковка архива (может занять немного времени)</translation>
    </message>
    <message>
        <location filename="../src/installwindow.cpp" line="222"/>
        <source>Cannot unpack archive:&lt;br /&gt;</source>
        <translation>Невозможно распаковать архив:&lt;br /&gt;</translation>
    </message>
    <message>
        <location filename="../src/installwindow.cpp" line="237"/>
        <source>Prepare directories</source>
        <translation>Подготовка каталогов</translation>
    </message>
    <message>
        <location filename="../src/installwindow.cpp" line="245"/>
        <source>Main property not found in Json: </source>
        <translation>Поле Main не найдено в appinfo.json: </translation>
    </message>
    <message>
        <location filename="../src/installwindow.cpp" line="266"/>
        <location filename="../src/installwindow.cpp" line="270"/>
        <source>Can&apos;t create directory %1</source>
        <translation>Не могу создать каталог %1</translation>
    </message>
    <message>
        <location filename="../src/installwindow.cpp" line="284"/>
        <source>Extracting game info</source>
        <translation>Извлечение информации об игре</translation>
    </message>
    <message>
        <location filename="../src/installwindow.cpp" line="304"/>
        <source>Cannot parse JSON: </source>
        <translation>Ошибка разбора JSON: </translation>
    </message>
    <message>
        <location filename="../src/installwindow.cpp" line="311"/>
        <source>Error parsing appinfo.json!</source>
        <translation>Ошибка парсера JSON!</translation>
    </message>
    <message>
        <location filename="../src/installwindow.cpp" line="316"/>
        <source>Seems to be wrong game or naming error!&lt;br /&gt;Ipk ID: %1&lt;br /&gt;Expected ID mask: %2</source>
        <translation>Ошибка в соответствии игры имени!&lt;br /&gt;ID из файла: %1&lt;br /&gt;Ожидаемая маска ID: %2</translation>
    </message>
    <message>
        <location filename="../src/installwindow.cpp" line="323"/>
        <source> by </source>
        <translation> от </translation>
    </message>
    <message>
        <location filename="../src/installwindow.cpp" line="336"/>
        <source>Checking available space</source>
        <translation>Проверка свободного места</translation>
    </message>
    <message>
        <location filename="../src/installwindow.cpp" line="347"/>
        <source>Available free space in /home/user/MyDocs directory is %1MB, but the game requires %2MB!</source>
        <translation>Доступное место в MyDocs каталоге - %1МБ, но игре нужно %2МБ!</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>%1 games available, %2 games installed</source>
        <translation type="obsolete">%1 игр доступно, %2 игр установлено</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="41"/>
        <source>Install</source>
        <translation>Установка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="42"/>
        <source>Saves</source>
        <translation>Сейвы</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/mainwindow.cpp" line="89"/>
        <source>%n games supported</source>
        <translation>
            <numerusform>%n игра поддерживается</numerusform>
            <numerusform>%n игры поддерживается</numerusform>
            <numerusform>%n игр поддерживается</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/mainwindow.cpp" line="90"/>
        <source>, %n games installed</source>
        <translation>
            <numerusform>, %n игра установлена</numerusform>
            <numerusform>, %n игры установлено</numerusform>
            <numerusform>, %n игр установлено</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/ui/mainwindow.ui" line="14"/>
        <location filename="../src/ui/mainwindow.ui" line="115"/>
        <source>WebOS Games</source>
        <translation>WebOS Игры</translation>
    </message>
    <message>
        <location filename="../src/ui/mainwindow.ui" line="30"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; color:#1f45d0;&quot;&gt;Games Info&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <source>WebOS Games Manager</source>
        <translation type="obsolete">Менеджер Игр WebOS</translation>
    </message>
    <message>
        <location filename="../src/ui/mainwindow.ui" line="142"/>
        <source>Install/Uninstall</source>
        <translation>Установка/Удаление</translation>
    </message>
    <message>
        <location filename="../src/ui/mainwindow.ui" line="163"/>
        <source>Manage Saves</source>
        <translation>Управление сейвами</translation>
    </message>
    <message>
        <location filename="../src/ui/mainwindow.ui" line="172"/>
        <location filename="../src/mainwindow.cpp" line="29"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
</context>
<context>
    <name>ManageWindow</name>
    <message>
        <location filename="../src/ui/managewindow.ui" line="14"/>
        <source>Install Games</source>
        <translation>Установка игр</translation>
    </message>
    <message>
        <location filename="../src/ui/managewindow.ui" line="158"/>
        <source>IPK File:</source>
        <translation>IPK файл:</translation>
    </message>
    <message>
        <location filename="../src/ui/managewindow.ui" line="239"/>
        <location filename="../src/managewindow.cpp" line="162"/>
        <location filename="../src/managewindow.cpp" line="198"/>
        <source>Install</source>
        <translation>Установить</translation>
    </message>
    <message>
        <location filename="../src/ui/managewindow.ui" line="207"/>
        <source>Play</source>
        <translation>Играть</translation>
    </message>
    <message>
        <location filename="../src/managewindow.cpp" line="27"/>
        <source>Refresh List</source>
        <translation>Обновить список</translation>
    </message>
    <message>
        <location filename="../src/managewindow.cpp" line="29"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/managewindow.cpp" line="110"/>
        <source>Space Required</source>
        <translation>Требует места</translation>
    </message>
    <message>
        <location filename="../src/managewindow.cpp" line="112"/>
        <source>MB</source>
        <translation>МБ</translation>
    </message>
    <message>
        <location filename="../src/managewindow.cpp" line="154"/>
        <location filename="../src/managewindow.cpp" line="199"/>
        <source>Find IPK file...</source>
        <translation>Найти .IPK файл...</translation>
    </message>
    <message>
        <location filename="../src/managewindow.cpp" line="166"/>
        <location filename="../src/managewindow.cpp" line="176"/>
        <source>Uninstall</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/managewindow.cpp" line="179"/>
        <source>Game installed</source>
        <translation>Игра установлена</translation>
    </message>
    <message>
        <location filename="../src/managewindow.cpp" line="181"/>
        <source> (version %1)</source>
        <translation> (версия %1)</translation>
    </message>
    <message>
        <location filename="../src/managewindow.cpp" line="196"/>
        <source>IPK file</source>
        <translation>IPK файл</translation>
    </message>
    <message>
        <location filename="../src/managewindow.cpp" line="201"/>
        <source>Found!</source>
        <translation>Найден!</translation>
    </message>
    <message>
        <location filename="../src/managewindow.cpp" line="204"/>
        <source>Not Found</source>
        <translation>Не найден</translation>
    </message>
    <message>
        <location filename="../src/managewindow.cpp" line="221"/>
        <source>Uninstall game?</source>
        <translation>Удалить игру?</translation>
    </message>
    <message>
        <location filename="../src/managewindow.cpp" line="222"/>
        <source>Are you sure you want to uninstall %1?&lt;br /&gt;You might want to backup your saves first.</source>
        <translation>Вы уверены, что хотите удалить игру %1?&lt;br /&gt;Возможно вы хотите сначала сохранить сейвы.</translation>
    </message>
</context>
<context>
    <name>SavesListDelegate</name>
    <message>
        <location filename="../src/gameslistdelegate.cpp" line="87"/>
        <source>Last backup: </source>
        <translation>Последнее сохранение: </translation>
    </message>
    <message>
        <location filename="../src/gameslistdelegate.cpp" line="89"/>
        <source>Never</source>
        <translation>Никогда</translation>
    </message>
</context>
<context>
    <name>SavesWindow</name>
    <message>
        <location filename="../src/ui/saveswindow.ui" line="14"/>
        <source>Manage Saves</source>
        <translation>Управление сейвами</translation>
    </message>
    <message>
        <location filename="../src/ui/saveswindow.ui" line="48"/>
        <source>Backup</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../src/ui/saveswindow.ui" line="64"/>
        <source>Restore</source>
        <translation>Восстановить</translation>
    </message>
    <message>
        <location filename="../src/saveswindow.cpp" line="27"/>
        <source>Backup All</source>
        <translation>Сохранить все</translation>
    </message>
    <message>
        <location filename="../src/saveswindow.cpp" line="29"/>
        <source>Restore All</source>
        <translation>Восстановить все</translation>
    </message>
    <message>
        <location filename="../src/saveswindow.cpp" line="84"/>
        <source>Can&apos;t create dir %1</source>
        <translation>Не могу создать каталог %1</translation>
    </message>
    <message>
        <location filename="../src/saveswindow.cpp" line="119"/>
        <source>Can&apos;t copy file %1 to %2</source>
        <translation>Невозможно скопировать %1 в %2</translation>
    </message>
    <message>
        <location filename="../src/saveswindow.cpp" line="143"/>
        <source>Can&apos;t find the directory %1&lt;br /&gt;Backup was created, butprobably deleted manually.</source>
        <translation>Не могу найти каталог %1&lt;br /&gt;Сейвы были сделаны, но возможно удалены вручную.</translation>
    </message>
    <message>
        <location filename="../src/saveswindow.cpp" line="163"/>
        <source>Can&apos;t find the file %1&lt;br /&gt;Backup was created, butprobably file was deleted manually.</source>
        <translation>Не могу найти файл %1&lt;br /&gt;Сейвы были сделаны, но возможно файл был удалён вручную.</translation>
    </message>
    <message>
        <location filename="../src/saveswindow.cpp" line="191"/>
        <source>Can&apos;t copy file %1 to %2&lt;br /&gt;Backup was created, butprobably file was deleted manually.</source>
        <translation>Невозможно скопировать файл %1 в %2&lt;br /&gt;Сейвы были сделаны, но возможно файлы удалены вручную.</translation>
    </message>
    <message>
        <location filename="../src/saveswindow.cpp" line="215"/>
        <source>Games information backed up</source>
        <translation>Сейвы для всех игры сохранены</translation>
    </message>
    <message>
        <location filename="../src/saveswindow.cpp" line="230"/>
        <source>Games information restored</source>
        <translation>Сейвы для всех игр восстановлены</translation>
    </message>
    <message>
        <location filename="../src/saveswindow.cpp" line="248"/>
        <source>Game information is saved</source>
        <translation>Сейв для игры сохранен</translation>
    </message>
    <message>
        <location filename="../src/saveswindow.cpp" line="254"/>
        <source>Game information restored</source>
        <translation>Сейв для игры восстановлен</translation>
    </message>
    <message>
        <location filename="../src/saveswindow.cpp" line="267"/>
        <source>Done!</source>
        <translation>ОК</translation>
    </message>
    <message>
        <location filename="../src/saveswindow.cpp" line="286"/>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
</context>
<context>
    <name>SettingsWindow</name>
    <message>
        <location filename="../src/ui/settingswindow.ui" line="14"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/ui/settingswindow.ui" line="62"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../src/ui/settingswindow.ui" line="81"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/ui/settingswindow.ui" line="88"/>
        <source>Defaults</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="59"/>
        <source>Downloads Dir</source>
        <translation>Каталог с .ipk файлами</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="60"/>
        <source>Data Dir</source>
        <translation>Каталог с файлами данных</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="61"/>
        <source>Bin Dir</source>
        <translation>Каталог с бинарными файлами</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="62"/>
        <source>Saves Dir</source>
        <translation>Каталог сэйвов</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="152"/>
        <source>Downloads Directory</source>
        <translation>Каталог с .ipk файлами</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="165"/>
        <source>Saves Directory</source>
        <translation>Каталог с сэйвами</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="177"/>
        <source>Binary Directory</source>
        <translation>Каталог с бинарными файлами</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="189"/>
        <source>Game Data Directory</source>
        <translation>Каталог с файлами данных игр</translation>
    </message>
</context>
<context>
    <name>UninstallWindow</name>
    <message>
        <location filename="../src/uninstallwindow.cpp" line="14"/>
        <source>Uninstalling</source>
        <translation>Удаление</translation>
    </message>
    <message>
        <location filename="../src/uninstallwindow.cpp" line="16"/>
        <source>Uninstall game</source>
        <translation>Удаление игры</translation>
    </message>
    <message>
        <location filename="../src/uninstallwindow.cpp" line="37"/>
        <source>Cleaning up</source>
        <translation>Очистка</translation>
    </message>
    <message>
        <location filename="../src/uninstallwindow.cpp" line="48"/>
        <location filename="../src/uninstallwindow.cpp" line="54"/>
        <location filename="../src/uninstallwindow.cpp" line="60"/>
        <source>Cannot delete file %1</source>
        <translation>Невозможно удалить файл %1</translation>
    </message>
    <message>
        <location filename="../src/uninstallwindow.cpp" line="67"/>
        <source>Game uninstalled successfully!</source>
        <translation>Игра успешно удалена!</translation>
    </message>
    <message>
        <location filename="../src/uninstallwindow.cpp" line="80"/>
        <source>Removing game</source>
        <translation>Удаление игры</translation>
    </message>
    <message>
        <location filename="../src/uninstallwindow.cpp" line="85"/>
        <location filename="../src/uninstallwindow.cpp" line="91"/>
        <source>Cannot delete dir %1</source>
        <translation>Невозможно удалить каталог %1</translation>
    </message>
    <message>
        <location filename="../src/uninstallwindow.cpp" line="105"/>
        <source>Checking directories</source>
        <translation>Проверка каталогов</translation>
    </message>
    <message>
        <location filename="../src/uninstallwindow.cpp" line="108"/>
        <source>Game Title is not found. That means some manual edit or program bug.</source>
        <translation>Не могу найти название игры. Это означает, что файл конфигурации был изменен вручную или ошибку программы.</translation>
    </message>
    <message>
        <location filename="../src/uninstallwindow.cpp" line="118"/>
        <source>Data directory %1 does not exist.&lt;br /&gt;This means some manual intervention or the program bug.</source>
        <translation>Каталог с данными %1 не существует&lt;br /&gt;Это означает ручное вмешательство или ошибку программы.</translation>
    </message>
    <message>
        <location filename="../src/uninstallwindow.cpp" line="125"/>
        <source>Bin directory %1 does not exist.&lt;br /&gt;This means some manual intervention or the program bug.</source>
        <translation>Каталог с бинарными данными %1 не найден.&lt;br /&gt;Это означает ручное вмешательство или ошибку программы.</translation>
    </message>
</context>
</TS>
